@@ -11,8 +11,10 @@ from marshmallow import fields, Schema, validate
 import paramtools
 import numpy as np
 
+from .exceptions import SerializationError
 
-__version__ = "1.2.0"
+
+__version__ = "1.3.1"
 
 Num = Union[int, float]
 JSONLike = Union[dict, str]
@@ -71,32 +73,38 @@ class Result(Schema):
     downloadable = fields.Nested(Output, many=True)
 
 
-def serialize(data):
-    def ser(obj):
-        if isinstance(obj, (datetime, date)):
-            return str(obj)
-        if isinstance(obj, np.ndarray):
-            return obj.tolist()
-        return obj
-    return json.loads(json.dumps(data, default=ser))
-
 class FunctionsTest:
 
-    def __init__(self, model_parameters: Callable, validate_inputs: Callable,
+    def __init__(self, get_inputs: Callable, validate_inputs: Callable,
                  run_model: Callable, ok_adjustment: dict, bad_adjustment: dict):
-        self.model_parameters = model_parameters
+        self.get_inputs = get_inputs
         self.validate_inputs = validate_inputs
         self.run_model = run_model
         self.ok_adjustment = ok_adjustment
         self.bad_adjustment = bad_adjustment
 
     def test(self):
-        self.test_model_parameters()
+        self.test_get_inputs()
         self.test_validate_inputs()
         self.test_run_model()
 
-    def test_model_parameters(self):
-        init_metaparams, init_modparams = self.model_parameters({})
+    def test_get_inputs(self):
+        init_metaparams, init_modparams = self.get_inputs({})
+
+        try:
+            json.dumps(init_metaparams)
+        except TypeError as e:
+            raise SerializationError(
+                (f"Meta parameters must be JSON serializable: \n\n\t{str(e)}\n"
+                 f"\nHint: try setting `serializable=True` in `Parameters.specification`.")
+            )
+        try:
+            json.dumps(init_modparams)
+        except TypeError as e:
+            raise SerializationError(
+                (f"Model parameters must be JSON serializable: \n\n\t{str(e)}\n"
+                 f"\nHint: try setting `serializable=True` in `Parameters.specification`.")
+            )
 
         class MetaParams(Parameters):
             array_first = True
@@ -118,14 +126,14 @@ class FunctionsTest:
         mp_grid = itertools.product(*mp_grid)
 
         for tup in mp_grid:
-            _, modparams_ = self.model_parameters(
+            _, modparams_ = self.get_inputs(
                 {mp_names[i]: tup[i] for i in range(len(mp_names))}
             )
             for modparams in modparams_.values():
                 assert params.load({"parameters": modparams})
 
     def test_validate_inputs(self):
-        init_metaparams, init_modparams = self.model_parameters({})
+        init_metaparams, init_modparams = self.get_inputs({})
 
         class MetaParams(Parameters):
             array_first = True
@@ -141,7 +149,7 @@ class FunctionsTest:
 
         ew_result = self.validate_inputs(mp_spec, self.ok_adjustment, copy.deepcopy(ew_template))
 
-        for major_sect, ew_dict in ew_result.items():
+        for _, ew_dict in ew_result.items():
             assert ew_schema.load(ew_dict)
             assert len(ew_dict.get("errors")) == 0
             assert len(ew_dict.get("warnings")) == 0
@@ -154,7 +162,7 @@ class FunctionsTest:
 
 
     def test_run_model(self):
-        init_metaparams, init_modparams = self.model_parameters({})
+        init_metaparams, init_modparams = self.get_inputs({})
 
         class MetaParams(Parameters):
             array_first = True
